@@ -29,7 +29,7 @@
 	((obj), E_TYPE_CALENDAR_SELECTOR, ECalendarSelectorPrivate))
 
 struct _ECalendarSelectorPrivate {
-	gint dummy_value;
+	EShellView *shell_view;
 };
 
 G_DEFINE_TYPE (
@@ -37,16 +37,25 @@ G_DEFINE_TYPE (
 	e_calendar_selector,
 	E_TYPE_CLIENT_SELECTOR)
 
+enum {
+	PROP_0,
+	PROP_SHELL_VIEW,
+};
+
 static gboolean
 calendar_selector_update_single_object (ECalClient *client,
                                         icalcomponent *icalcomp)
 {
 	gchar *uid;
-	icalcomponent *tmp_icalcomp;
+	icalcomponent *tmp_icalcomp = NULL;
+	gboolean success;
 
 	uid = (gchar *) icalcomponent_get_uid (icalcomp);
 
-	if (e_cal_client_get_object_sync (client, uid, NULL, &tmp_icalcomp, NULL, NULL)) {
+	e_cal_client_get_object_sync (
+		client, uid, NULL, &tmp_icalcomp, NULL, NULL);
+
+	if (tmp_icalcomp != NULL) {
 		icalcomponent_free (tmp_icalcomp);
 
 		return e_cal_client_modify_object_sync (
@@ -54,14 +63,15 @@ calendar_selector_update_single_object (ECalClient *client,
 	}
 
 	uid = NULL;
-	if (!e_cal_client_create_object_sync (client, icalcomp, &uid, NULL, NULL))
-		return FALSE;
+	success = e_cal_client_create_object_sync (
+		client, icalcomp, &uid, NULL, NULL);
 
-	if (uid)
+	if (uid != NULL) {
 		icalcomponent_set_uid (icalcomp, uid);
-	g_free (uid);
+		g_free (uid);
+	}
 
-	return TRUE;
+	return success;
 }
 
 static gboolean
@@ -146,6 +156,64 @@ client_connect_cb (GObject *source_object,
 	icalcomponent_free (icalcomp);
 }
 
+static void
+calendar_selector_set_shell_view (ECalendarSelector *selector,
+                                  EShellView *shell_view)
+{
+	g_return_if_fail (E_IS_SHELL_VIEW (shell_view));
+	g_return_if_fail (selector->priv->shell_view == NULL);
+
+	selector->priv->shell_view = g_object_ref (shell_view);
+}
+
+static void
+calendar_selector_set_property (GObject *object,
+                                guint property_id,
+                                const GValue *value,
+                                GParamSpec *pspec)
+{
+	switch (property_id) {
+		case PROP_SHELL_VIEW:
+			calendar_selector_set_shell_view (
+				E_CALENDAR_SELECTOR (object),
+				g_value_get_object (value));
+			return;
+	}
+
+	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+}
+
+static void
+calendar_selector_get_property (GObject *object,
+                                guint property_id,
+                                GValue *value,
+                                GParamSpec *pspec)
+{
+	switch (property_id) {
+		case PROP_SHELL_VIEW:
+			g_value_set_object (
+				value,
+				e_calendar_selector_get_shell_view (
+				E_CALENDAR_SELECTOR (object)));
+			return;
+	}
+
+	G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+}
+
+static void
+calendar_selector_dispose (GObject *object)
+{
+	ECalendarSelectorPrivate *priv;
+
+	priv = E_CALENDAR_SELECTOR_GET_PRIVATE (object);
+
+	g_clear_object (&priv->shell_view);
+
+	/* Chain up to the parent' s dispose() method. */
+	G_OBJECT_CLASS (e_calendar_selector_parent_class)->dispose (object);
+}
+
 static void
 calendar_selector_constructed (GObject *object)
 {
@@ -217,9 +285,24 @@ e_calendar_selector_class_init (ECalendarSelectorClass *class)
 
 	object_class = G_OBJECT_CLASS (class);
 	object_class->constructed = calendar_selector_constructed;
+	object_class->set_property = calendar_selector_set_property;
+	object_class->get_property = calendar_selector_get_property;
+	object_class->dispose = calendar_selector_dispose;
 
 	source_selector_class = E_SOURCE_SELECTOR_CLASS (class);
 	source_selector_class->data_dropped = calendar_selector_data_dropped;
+
+	g_object_class_install_property (
+		object_class,
+		PROP_SHELL_VIEW,
+		g_param_spec_object (
+			"shell-view",
+			NULL,
+			NULL,
+			E_TYPE_SHELL_VIEW,
+			G_PARAM_READWRITE |
+			G_PARAM_CONSTRUCT_ONLY |
+			G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -235,12 +318,14 @@ e_calendar_selector_init (ECalendarSelector *selector)
 }
 
 GtkWidget *
-e_calendar_selector_new (EClientCache *client_cache)
+e_calendar_selector_new (EClientCache *client_cache,
+                         EShellView *shell_view)
 {
 	ESourceRegistry *registry;
 	GtkWidget *widget;
 
 	g_return_val_if_fail (E_IS_CLIENT_CACHE (client_cache), NULL);
+	g_return_val_if_fail (E_IS_SHELL_VIEW (shell_view), NULL);
 
 	registry = e_client_cache_ref_registry (client_cache);
 
@@ -248,9 +333,20 @@ e_calendar_selector_new (EClientCache *client_cache)
 		E_TYPE_CALENDAR_SELECTOR,
 		"client-cache", client_cache,
 		"extension-name", E_SOURCE_EXTENSION_CALENDAR,
-		"registry", registry, NULL);
+		"registry", registry,
+		"shell-view", shell_view,
+		NULL);
 
 	g_object_unref (registry);
 
 	return widget;
 }
+
+EShellView *
+e_calendar_selector_get_shell_view (ECalendarSelector *selector)
+{
+	g_return_val_if_fail (E_IS_CALENDAR_SELECTOR (selector), NULL);
+
+	return selector->priv->shell_view;
+}
+
