@@ -98,7 +98,7 @@ empe_message_parse (EMailParserExtension *extension,
 	 * sense to collapse the message body if we can render it. */
 	mail_part = g_queue_peek_head (&work_queue);
 	if (mail_part != NULL) {
-		if (mail_part->is_attachment) {
+		if (e_mail_part_get_is_attachment (mail_part)) {
 			e_mail_parser_wrap_as_attachment (
 				parser, part, part_id, &work_queue);
 
