@@ -769,37 +769,31 @@ toggle_headers_visibility (WebKitDOMElement *button,
 	d (printf ("Headers %s!\n", expanded ? "collapsed" : "expanded"));
 }
 
-static const gchar *addresses[] = { "to", "cc", "bcc" };
-
 static void
 toggle_address_visibility (WebKitDOMElement *button,
-                           WebKitDOMEvent *event,
-                           const gchar *address)
+                           WebKitDOMEvent *event)
 {
 	WebKitDOMElement *full_addr, *ellipsis;
+	WebKitDOMElement *parent;
 	WebKitDOMCSSStyleDeclaration *css_full, *css_ellipsis;
-	WebKitDOMDocument *document;
-	gchar *id;
 	const gchar *path;
 	gboolean expanded;
 
-	document = webkit_dom_node_get_owner_document (
-		WEBKIT_DOM_NODE (button));
+	/* <b> element */
+	parent = webkit_dom_node_get_parent_element (WEBKIT_DOM_NODE (button));
+	/* <td> element */
+	parent = webkit_dom_node_get_parent_element (WEBKIT_DOM_NODE (parent));
 
-	id = g_strconcat ("__evo-moreaddr-", address, NULL);
-	full_addr = webkit_dom_document_get_element_by_id (document, id);
-	g_free (id);
+	full_addr = webkit_dom_element_query_selector (parent, "#__evo-moreaddr", NULL);
 
-	if (full_addr == NULL)
+	if (!full_addr)
 		return;
 
 	css_full = webkit_dom_element_get_style (full_addr);
 
-	id = g_strconcat ("__evo-moreaddr-ellipsis-", address, NULL);
-	ellipsis = webkit_dom_document_get_element_by_id (document, id);
-	g_free (id);
+	ellipsis = webkit_dom_element_query_selector (parent, "#__evo-moreaddr-ellipsis", NULL);
 
-	if (ellipsis == NULL)
+	if (!ellipsis)
 		return;
 
 	css_ellipsis = webkit_dom_element_get_style (ellipsis);
@@ -819,11 +813,9 @@ toggle_address_visibility (WebKitDOMElement *button,
 		path = "evo-file://" EVOLUTION_IMAGESDIR "/minus.png";
 
 	if (!WEBKIT_DOM_IS_HTML_IMAGE_ELEMENT (button)) {
-		id = g_strconcat ("__evo-moreaddr-img-", address, NULL);
-		button = webkit_dom_document_get_element_by_id (document, id);
-		g_free (id);
+		button = webkit_dom_element_query_selector (parent, "#__evo-moreaddr-img", NULL);
 
-		if (button == NULL)
+		if (!button)
 			return;
 	}
 
@@ -831,6 +823,60 @@ toggle_address_visibility (WebKitDOMElement *button,
 		WEBKIT_DOM_HTML_IMAGE_ELEMENT (button), path);
 }
 
+static void
+add_color_css_rule_for_web_view (EWebView *view,
+				 const char *color_name,
+				 const char *color_value)
+{
+	gchar *selector;
+	gchar *style;
+
+	selector = g_strconcat (".-e-mail-formatter-", color_name, NULL);
+
+	if (g_strstr_len (color_name, -1, "header"))
+		style = g_strconcat ("color: ", color_value, " !important;", NULL);
+	else if (g_strstr_len (color_name, -1, "frame"))
+		style = g_strconcat ("border-color: ", color_value, " !important;", NULL);
+	else
+		style = g_strconcat ("background-color: ", color_value, " !important;", NULL);
+
+	e_web_view_add_css_rule_into_style_sheet (
+		view,
+		"-e-mail-formatter-style-sheet",
+		selector,
+		style);
+
+	g_free (style);
+	g_free (selector);
+}
+
+static void
+initialize_web_view_colors (EMailDisplay *display)
+{
+	EMailFormatter *formatter;
+	const gchar *color_names [] = { "body-color", "citation-color",
+					"frame-color", "header-color", NULL };
+	gint ii;
+
+	formatter = e_mail_display_get_formatter (display);
+
+	for (ii = 0; color_names[ii]; ii++) {
+		GdkRGBA *color = NULL;
+		gchar *color_value;
+
+		g_object_get (formatter, color_names[ii], &color, NULL);
+		color_value = g_strdup_printf ("#%06x", e_rgba_to_value (color));
+
+		add_color_css_rule_for_web_view (
+			E_WEB_VIEW (display),
+			color_names[ii],
+			color_value);
+
+		gdk_rgba_free (color);
+		g_free (color_value);
+	}
+}
+
 static void
 setup_dom_bindings (GObject *object,
                     GParamSpec *pspec,
@@ -841,7 +887,8 @@ setup_dom_bindings (GObject *object,
 	WebKitLoadStatus load_status;
 	WebKitDOMDocument *document;
 	WebKitDOMElement *button;
-	gint ii = 0;
+	WebKitDOMNodeList *list;
+	gint length, ii = 0;
 
 	frame = WEBKIT_WEB_FRAME (object);
 	load_status = webkit_web_frame_get_load_status (frame);
@@ -859,33 +906,17 @@ setup_dom_bindings (GObject *object,
 			G_CALLBACK (toggle_headers_visibility),
 			FALSE, web_view);
 
-	for (ii = 0; ii < 3; ii++) {
-		gchar *id;
+	list = webkit_dom_document_query_selector_all (document, "*[id^=__evo-moreaddr-]", NULL);
 
-		id = g_strconcat ("__evo-moreaddr-img-", addresses[ii], NULL);
-		button = webkit_dom_document_get_element_by_id (document, id);
-		g_free (id);
+	length = webkit_dom_node_list_get_length (list);
 
-		if (button == NULL)
-			continue;
+	for (ii = 0; ii < length; ii++) {
+		button = WEBKIT_DOM_ELEMENT (webkit_dom_node_list_item (list, ii));
 
 		webkit_dom_event_target_add_event_listener (
 			WEBKIT_DOM_EVENT_TARGET (button), "click",
 			G_CALLBACK (toggle_address_visibility), FALSE,
-			(gpointer) addresses[ii]);
-
-		id = g_strconcat (
-			"__evo-moreaddr-ellipsis-", addresses[ii], NULL);
-		button = webkit_dom_document_get_element_by_id (document, id);
-		g_free (id);
-
-		if (button == NULL)
-			continue;
-
-		webkit_dom_event_target_add_event_listener (
-			WEBKIT_DOM_EVENT_TARGET (button), "click",
-			G_CALLBACK (toggle_address_visibility), FALSE,
-			(gpointer) addresses[ii]);
+			NULL);
 	}
 }
 
@@ -914,6 +945,7 @@ mail_parts_bind_dom (GObject *object,
 	if (display->priv->part_list == NULL)
 		return;
 
+	initialize_web_view_colors (display);
 	frame_name = webkit_web_frame_get_name (frame);
 	if (frame_name == NULL || *frame_name == '\0')
 		frame_name = ".message.headers";
@@ -1535,6 +1567,30 @@ e_mail_display_init (EMailDisplay *display)
 	}
 }
 
+static void
+e_mail_display_update_colors (EMailDisplay *display,
+                              GParamSpec *param_spec,
+                              EMailFormatter *formatter)
+{
+	GdkRGBA *color = NULL;
+	gchar *color_value;
+
+	g_return_if_fail (E_IS_MAIL_DISPLAY (display));
+	g_return_if_fail (E_IS_MAIL_FORMATTER (formatter));
+
+	g_object_get (formatter, param_spec->name, &color, NULL);
+
+	color_value = g_strdup_printf ("#%06x", e_rgba_to_value (color));
+
+	add_color_css_rule_for_web_view (
+		E_WEB_VIEW (display),
+		param_spec->name,
+		color_value);
+
+	gdk_rgba_free (color);
+	g_free (color_value);
+}
+
 GtkWidget *
 e_mail_display_new (void)
 {
@@ -1592,18 +1648,14 @@ e_mail_display_set_mode (EMailDisplay *display,
 			G_CALLBACK (e_mail_display_reload), display,
 		"swapped-object-signal::notify::animate-images",
 			G_CALLBACK (e_mail_display_reload), display,
-		"swapped-object-signal::notify::text-color",
-			G_CALLBACK (e_mail_display_reload), display,
 		"swapped-object-signal::notify::body-color",
-			G_CALLBACK (e_mail_display_reload), display,
+			G_CALLBACK (e_mail_display_update_colors), display,
 		"swapped-object-signal::notify::citation-color",
-			G_CALLBACK (e_mail_display_reload), display,
-		"swapped-object-signal::notify::content-color",
-			G_CALLBACK (e_mail_display_reload), display,
+			G_CALLBACK (e_mail_display_update_colors), display,
 		"swapped-object-signal::notify::frame-color",
-			G_CALLBACK (e_mail_display_reload), display,
+			G_CALLBACK (e_mail_display_update_colors), display,
 		"swapped-object-signal::notify::header-color",
-			G_CALLBACK (e_mail_display_reload), display,
+			G_CALLBACK (e_mail_display_update_colors), display,
 		"swapped-object-signal::need-redraw",
 			G_CALLBACK (e_mail_display_reload), display,
 		NULL);
@@ -1854,7 +1906,7 @@ e_mail_display_set_status (EMailDisplay *display,
 		"<meta name=\"generator\" content=\"Evolution Mail\"/>\n"
 		"<title>Evolution Mail Display</title>\n"
 		"</head>\n"
-		"<body bgcolor=\"#%06x\" text=\"#%06x\">"
+		"<body class=\"-e-web-view-background-color e-web-view-text-color\">"
 		"  <style>html, body { height: 100%%; }</style>\n"
 		"  <table border=\"0\" width=\"100%%\" height=\"100%%\">\n"
 		"    <tr height=\"100%%\" valign=\"middle\">\n"
@@ -1865,14 +1917,6 @@ e_mail_display_set_status (EMailDisplay *display,
 		"  </table>\n"
 		"</body>\n"
 		"</html>\n",
-		e_rgba_to_value (
-			e_mail_formatter_get_color (
-				display->priv->formatter,
-				E_MAIL_FORMATTER_COLOR_CONTENT)),
-		e_rgba_to_value (
-			e_mail_formatter_get_color (
-				display->priv->formatter,
-				E_MAIL_FORMATTER_COLOR_TEXT)),
 		status);
 
 	e_web_view_load_string (E_WEB_VIEW (display), str);
